package com.jjt.inventory.domain;

import com.baomidou.mybatisplus.annotation.TableId;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.jjt.common.annotation.Excel;
import com.jjt.common.core.domain.BaseEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.Date;

/**
 * 白坯仓库小时数据对象 TWIN_CALC_HOUR_BP
 *
 * @author wukai
 * @date 2025-06-10
 */
@ApiModel(value = "TwinCalcHourBp", description = "白坯仓库小时数据")
@NoArgsConstructor
@Data
public class TwinCalcHourBp extends BaseEntity {
    private static final long serialVersionUID = 1L;


    /**
     * ID
     */
    @ApiModelProperty("ID")
    @TableId
    private Long id;

    /**
     * 日期
     */
    @ApiModelProperty("日期")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "日期", width = 30, dateFormat = "yyyy-MM-dd")
    private Date dataDate;

    /**
     * 小时;0-23
     */
    @ApiModelProperty("小时;0-23")
    @Excel(name = "小时;0-23")
    private Integer hour;

    /**
     * 数据名称
     */
    @ApiModelProperty("数据名称")
    @Excel(name = "数据名称")
    private String name;

    /**
     * SKU
     */
    @ApiModelProperty("SKU")
    @Excel(name = "SKU")
    private String sku;

    /**
     * 平方米克重
     */
    @ApiModelProperty("平方米克重")
    @Excel(name = "平方米克重")
    private Integer mick;

    /**
     * 入库数量-卷
     */
    @ApiModelProperty("入库数量-卷")
    @Excel(name = "入库数量-卷")
    private Integer rollIn;

    /**
     * 出库数量-卷
     */
    @ApiModelProperty("出库数量-卷")
    @Excel(name = "出库数量-卷")
    private Integer rollOut;

    /**
     * 当前库存-卷
     */
    @ApiModelProperty("当前库存-卷")
    @Excel(name = "当前库存-卷")
    private Integer rollNum;

    /**
     * 入库数量-米
     */
    @ApiModelProperty("入库数量-米")
    @Excel(name = "入库数量-米")
    private Integer meterIn;

    /**
     * 出库数量-米
     */
    @ApiModelProperty("出库数量-米")
    @Excel(name = "出库数量-米")
    private Integer meterOut;

    /**
     * 当前库存-米
     */
    @ApiModelProperty("当前库存-米")
    @Excel(name = "当前库存-米")
    private Integer meterNum;

    /**
     * 入库数量-重
     */
    @ApiModelProperty("入库数量-重")
    @Excel(name = "入库数量-重")
    private Integer weightIn;

    /**
     * 出库数量-重
     */
    @ApiModelProperty("出库数量-重")
    @Excel(name = "出库数量-重")
    private Integer weightOut;

    /**
     * 当前库存-重
     */
    @ApiModelProperty("当前库存-重")
    @Excel(name = "当前库存-重")
    private Integer weightNum;

    /**
     * 创建人
     */
    @ApiModelProperty("创建人")
    @Excel(name = "创建人")
    private String createdBy;

    /**
     * 创建时间
     */
    @ApiModelProperty("创建时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "创建时间", width = 30, dateFormat = "yyyy-MM-dd")
    private Date createdTime;

    /**
     * 更新人
     */
    @ApiModelProperty("更新人")
    @Excel(name = "更新人")
    private String updatedBy;

    /**
     * 更新时间
     */
    @ApiModelProperty("更新时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "更新时间", width = 30, dateFormat = "yyyy-MM-dd")
    private Date updatedTime;


    public TwinCalcHourBp(boolean flag) {
        this.mick = 0;
        this.rollIn = 0;
        this.rollOut = 0;
        this.rollNum = 0;
        this.meterIn = 0;
        this.meterOut = 0;
        this.meterNum = 0;
        this.weightIn = 0;
        this.weightOut = 0;
        this.weightNum = 0;
    }

    /**
     * 增加平方米克重
     */
    public void addMick(Integer value) {
        this.mick += value;
    }

    /**
     * 增加入库数量-卷
     */
    public void addRollIn(Integer value) {
        this.rollIn += value;
    }

    /**
     * 增加出库数量-卷
     */
    public void addRollOut(Integer value) {
        this.rollOut += value;
    }

    /**
     * 增加当前库存-卷
     */
    public void addRollNum(Integer value) {
        this.rollNum += value;
    }

    /**
     * 增加入库数量-米
     */
    public void addMeterIn(Integer value) {
        this.meterIn += value;
    }

    /**
     * 增加出库数量-米
     */
    public void addMeterOut(Integer value) {
        this.meterOut += value;
    }

    /**
     * 增加当前库存-米
     */
    public void addMeterNum(Integer value) {
        this.meterNum += value;
    }

    /**
     * 增加入库数量-重
     */
    public void addWeightIn(Integer value) {
        this.weightIn += value;
    }

    /**
     * 增加出库数量-重
     */
    public void addWeightOut(Integer value) {
        this.weightOut += value;
    }

    /**
     * 增加当前库存-重
     */
    public void addWeightNum(Integer value) {
        this.weightNum += value;
    }

}
